@@ -30,6 +30,7 @@ from ormar.decorators import (  # noqa: I100
     post_relation_remove,
     post_save,
     post_update,
+    post_bulk_update,
     pre_delete,
     pre_relation_add,
     pre_relation_remove,
@@ -113,6 +114,7 @@ __all__ = [
     "RelationProtocol",
     "ModelMeta",
     "property_field",
+    "post_bulk_update",
     "post_delete",
     "post_save",
     "post_update",
